"""
tf2-sku
Format TF2 items as strings or objects.
"""

__title__ = "tf2-sku"
__author__ = "offish"
__license__ = "MIT"
__version__ = "2.0.0"

from .sku import to_sku, from_sku
from .utils import SKU, MAPPING
